@@ -52,8 +52,8 @@ public:
 
 LearnerProfile::ProfileManagerPrivate::ProfileManagerPrivate()
     : m_profiles(QList<Learner*>())
-    , m_activeProfile(0)
-    , m_config(0)
+    , m_activeProfile(nullptr)
+    , m_config(nullptr)
 {
     // load all profiles from storage
     m_goals.append(m_storage.loadGoals());
@@ -81,7 +81,7 @@ LearnerProfile::ProfileManagerPrivate::ProfileManagerPrivate()
             break;
         }
     }
-    if (m_activeProfile == 0) {
+    if (m_activeProfile == nullptr) {
         qCDebug(LIBLEARNER_LOG) << "No last active profile found, falling back to first found profile";
         if (m_profiles.size() > 0) {
             m_activeProfile = m_profiles.at(0);
@@ -157,11 +157,11 @@ int ProfileManager::profileCount() const
 
 void ProfileManager::openImageFileDialog()
 {
-    QString imageUrl = QFileDialog::getOpenFileName(0,
+    const QString imagePath = QFileDialog::getOpenFileName(0,
         i18n("Open Image"),
         "",
         i18n("Image Files (*.png *.jpg *.bmp)"));
-    d->m_activeProfile->importImage(imageUrl);
+    d->m_activeProfile->importImage(imagePath);
 }
 
 Learner * ProfileManager::addProfile(const QString &name)
@@ -204,8 +204,8 @@ void ProfileManager::removeProfile(Learner *learner)
     d->m_storage.removeProfile(learner);
 
     if (d->m_activeProfile == learner) {
-        if (d->m_profiles.count() == 0) {
-            setActiveProfile(0);
+        if (d->m_profiles.isEmpty()) {
+            setActiveProfile(nullptr);
         }
         else {
             setActiveProfile(d->m_profiles.at(0));
@@ -222,7 +222,7 @@ void ProfileManager::removeLearningGoal(Learner* learner, LearningGoal* goal)
 Learner * ProfileManager::profile(int index)
 {
     if (index < 0 || index >= profiles().count()) {
-        return 0;
+        return nullptr;
     }
     return profiles().at(index);
 }
@@ -232,7 +232,9 @@ QList< LearningGoal* > ProfileManager::goals() const
     return d->m_goals;
 }
 
-void ProfileManager::registerGoal(LearningGoal::Category category, const QString &identifier, const QString &name)
+void ProfileManager::registerGoal(LearningGoal::Category category,
+                                  const QString &identifier,
+                                  const QString &name)
 {
     // test whether goal is already registered
     foreach (LearningGoal *cmpGoal, d->m_goals) {
@@ -246,6 +248,38 @@ void ProfileManager::registerGoal(LearningGoal::Category category, const QString
     d->m_storage.storeGoal(goal);
 }
 
+LearnerProfile::LearningGoal * LearnerProfile::ProfileManager::goal(
+    LearningGoal::Category category,
+    const QString& identifier) const
+{
+    foreach (LearningGoal *goal, d->m_goals) {
+        if (goal->category() != category) {
+            continue;
+        }
+        if (goal->identifier() != identifier) {
+            continue;
+        }
+        return goal;
+    }
+    qCWarning(LIBLEARNER_LOG) << "no goal found for:" << category << identifier;
+    return nullptr;
+}
+
+void ProfileManager::recordProgress(Learner *learner,
+                                    LearningGoal *goal,
+                                    const QString &container, const QString &item,
+                                    int logPayload, int valuePayload)
+{
+    d->m_storage.storeProgressLog(learner, goal, container, item, logPayload, QDateTime::currentDateTime());
+    d->m_storage.storeProgressValue(learner, goal, container, item, valuePayload);
+}
+
+QHash<QString, int> ProfileManager::progressValues(Learner *learner, LearningGoal *goal,
+                       const QString &container) const
+{
+    return d->m_storage.readProgressValues(learner, goal, container);
+}
+
 void ProfileManager::sync()
 {
     d->sync();
