@@ -36,7 +36,7 @@ int main(int argc, char **argv)
                          ARTIKULATE_VERSION_STRING,
                          ki18nc("@title KAboutData: short program description", "Artikulate Pronunciation Trainer").toString(),
                          KAboutLicense::GPL_V2,
-                         ki18nc("@info:credit", "(c) 2013-2015 The Artikulate Developers").toString(),
+                         ki18nc("@info:credit", "(c) 2013-2016 The Artikulate Developers").toString(),
                          ki18nc("@title Short program description", "Training your pronunciation in a foreign language.").toString()
                         );
 
@@ -56,11 +56,10 @@ int main(int argc, char **argv)
 
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
-    // TODO: for >=KF5.15 use KCrash::initialize();
-    KCrash::setCrashHandler(KCrash::defaultCrashHandler);
-
     Application app(argc, argv);
     KAboutData::setApplicationData(aboutData);
+    KLocalizedString::setApplicationDomain("artikulate");
+    KCrash::initialize();
     new MainWindow();
 
     return app.exec();
